@@ -550,7 +550,7 @@ void NGraph::output_bubble( char dir, idx_dir u, idx_dir l, idx_dir open, idx_di
 bool NGraph::follow_path(idx_dir prev, idx_dir curr, idx_dir &next) const
 {
   if ( get_out_degree( curr.first, curr.second ) != 1
-    && get_out_degree(  curr.first, reverse_dir( curr.second ) ) != 1 )
+    || get_out_degree(  curr.first, reverse_dir( curr.second ) ) != 1 )
   {
     return false;
   }
